formTest
open | /Plone/@@p.a.jqt.testPage |
click | taform |
verifyTextPresent | Test Form |
pause | 500 |
verifyTextPresent | exact:ajax_load: |
type | Password | xxx
click | //input[@name='Check' and @value='3'] |
click | //input[@name='Radio' and @value='3'] |
click | submitButton |
pause | 500 |
verifyTextPresent | exact:Multiple:one |
verifyTextPresent | exact:Name:MyName1 |
verifyTextPresent | exact:Single2:A |
verifyTextPresent | exact:Single:one |
verifyTextPresent | exact:Radio:3 |
verifyTextPresent | exact:Text:This is Form1 |
verifyTextPresent | exact:submitButton:Submit1 |
verifyTextPresent | exact:Hidden:hiddenValue |
verifyTextPresent | exact:Password:xxx |
verifyTextPresent | exact:Check:3 |
click | //input[@name='submitButton' and @value='Submit2'] |
pause | 500 |
verifyTextPresent | exact:submitButton:Submit2 |
click | //button[@name='submitButton'] |
pause | 500 |
verifyTextPresent | exact:submitButton:Submit5 |
click | submitButton6 |